const db = require('../../models');

exports.createQuiz=async(req,res)=>{
    const {title,description} = req.body;
    try{
        await db.quiz.create({title,description});
        return res.json({message:'Quiz created successfully'});
    }
    catch(err){
        return res.json({message:'Unable to create quiz', error: err.message });
    }
};

exports.createQuestion = async (req, res) => {
  const { quiz_id, question_text,options,correct_answer } = req.body;
  try {
    const question=await db.question.create({quiz_id,question_text});
    const option=options.map((opt)=>({
      question_id:question.id,
      option_text:opt,
      is_correct:opt===correct_answer,
    }));
    await db.option.bulkCreate(option);
    return res.json({ message: 'Question and options created successfully' });
  } catch (err) {
    return res.json({ message: 'Unable to create question', error: err.message });
  }
};

exports.assignQuiz = async (req, res) => {
  const { user_id, quiz_id } = req.body;
  try {
    await db.user_quizzes.create({user_id, quiz_id, status:'pending'});
    return res.json({ message: 'Quiz assigned to user successfully' });
  } catch (err) {
    return res.json({ message: 'Unable to assign quiz', error: err.message });
  }
};

exports.getUserResult = async (req, res) => {
  const { user_id, quiz_id } = req.params;

  try {
    const answers = await db.user_answer.findAll({
      where: { user_id, quiz_id },
      include: [
        {
          model: db.question,
          attributes: ['question_text'],
          include: [
            {
              model: db.option,
              as: 'correctOption',
              where: { is_correct: true },
              required: false,
              attributes: ['option_text'],
            },
          ],
        },
        {
          model: db.option,
          as: 'selectedOption',
          foreignKey: 'answer',
          attributes: ['option_text'],
        },
      ],
    });

    const summary = await db.result.findOne({
      where: { user_id, quiz_id },
    });

    return res.json({
      score: summary?.score || 0,
      total: summary?.total || 0,
      answers,
    });
  } catch (err) {
    return res.status(500).json({ message: 'Error fetching user result', error: err.message });
  }
};

