const db = require('../../models');

exports.takeQuiz=async(req,res)=>{
    const {quiz_id,user_id}=req.params;
    try{
        const assigned =await db.user_quizzes.findOne({where:{user_id,quiz_id,status:'pending'}});
        if(!assigned){
            return res.json({message:'Quiz completed or not assigned properly'});
        }
        const quiz=await db.quiz.findByPk(quiz_id,{
          attributes:['id','title','description'],
          include:{
            model:db.question,
            attributes:['id','question_text'],
            include:{
              model:db.option,
              attributes:['id','option_text']
            }
          },
          order:[
            [db.question,'id','ASC'],
            [db.question,db.option,'id','ASC']
          ]
        });
        if(!quiz){
          return res.json({message:'Quiz not found'});
        }
        return res.json({quiz});
    }
    catch(err){
        return res.json({message:"Error fetching quiz",error:err.message});
    }
};

exports.submitQuiz = async (req, res) => {
  const { user_id, quiz_id, answers } = req.body;
  try {
    let score = 0;
    const total = answers.length;
    for (const ans of answers) {
      const correct= await db.option.findOne({where:{id:ans.selected_option_id}});
      const isCorrect = correct[0]?.is_correct === 1 ? 1 : 0;
      if (isCorrect) score++;
      await db.user_answer.create({user_id, quiz_id, question_id:ans.question_id, answer:ans.selected_option_id, is_correct:isCorrect});
    }
    await db.results.create({user_id, quiz_id, score, total});
    await db.user_quizzes.update({status:'completed'},{where:{user_id,quiz_id}});
    return res.json({ message: 'Quiz submitted', score, total });
  } catch (err) {
    return res.status(500).json({ message: 'Error submitting quiz', error: err.message });
  }
};














